==> polkit-0.116-i586-1.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/polkit-1/rules.d/20-plugdev-group-mount-override.rules.new
config etc/polkit-1/rules.d/10-org.freedesktop.NetworkManager.rules.new

# Make sure the polkitd user and group exist:
if ! grep -q "^polkitd:" etc/passwd ; then
  echo "polkitd:x:87:87:PolicyKit daemon owner:/var/lib/polkit:/bin/false" >> etc/passwd
fi
if ! grep -q "^polkitd:" etc/group ; then
  echo "polkitd:x:87:" >> etc/group
fi

# Remove obsolete rules:
rm -f etc/polkit-1/localauthority/50-local.d/*.pkla{,.new}
rm -f etc/polkit-1/rules.d/*.pkla{,.new}

# Remove obsolete directory:
rmdir etc/polkit-1/localauthority/50-local.d 2> /dev/null
rmdir etc/polkit-1/localauthority 2> /dev/null

( cd usr/doc/polkit-0.116 ; rm -rf html )
( cd usr/doc/polkit-0.116 ; ln -sf ../../share/gtk-doc/html/polkit-1 html )
( cd usr/lib ; rm -rf libpolkit-agent-1.so )
( cd usr/lib ; ln -sf libpolkit-agent-1.so.0.0.0 libpolkit-agent-1.so )
( cd usr/lib ; rm -rf libpolkit-agent-1.so.0 )
( cd usr/lib ; ln -sf libpolkit-agent-1.so.0.0.0 libpolkit-agent-1.so.0 )
( cd usr/lib ; rm -rf libpolkit-gobject-1.so )
( cd usr/lib ; ln -sf libpolkit-gobject-1.so.0.0.0 libpolkit-gobject-1.so )
( cd usr/lib ; rm -rf libpolkit-gobject-1.so.0 )
( cd usr/lib ; ln -sf libpolkit-gobject-1.so.0.0.0 libpolkit-gobject-1.so.0 )

==> polkit-0.117-i586-1.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/polkit-1/rules.d/20-plugdev-group-mount-override.rules.new
config etc/polkit-1/rules.d/10-org.freedesktop.NetworkManager.rules.new
if [ -r etc/pam.d/polkit-1.new ]; then
  config etc/pam.d/polkit-1.new
fi

# Make sure the polkitd user and group exist:
if ! grep -q "^polkitd:" etc/passwd ; then
  echo "polkitd:x:87:87:PolicyKit daemon owner:/var/lib/polkit:/bin/false" >> etc/passwd
fi
if ! grep -q "^polkitd:" etc/group ; then
  echo "polkitd:x:87:" >> etc/group
fi

# Remove obsolete rules:
rm -f etc/polkit-1/localauthority/50-local.d/*.pkla{,.new}
rm -f etc/polkit-1/rules.d/*.pkla{,.new}

# Remove obsolete directory:
rmdir etc/polkit-1/localauthority/50-local.d 2> /dev/null
rmdir etc/polkit-1/localauthority 2> /dev/null

( cd usr/doc/polkit-0.117 ; rm -rf INSTALL )
( cd usr/doc/polkit-0.117 ; ln -sf /usr/share/automake-1.16/INSTALL INSTALL )
( cd usr/doc/polkit-0.117 ; rm -rf html )
( cd usr/doc/polkit-0.117 ; ln -sf ../../share/gtk-doc/html/polkit-1 html )
( cd usr/lib ; rm -rf libpolkit-agent-1.so )
( cd usr/lib ; ln -sf libpolkit-agent-1.so.0.0.0 libpolkit-agent-1.so )
( cd usr/lib ; rm -rf libpolkit-agent-1.so.0 )
( cd usr/lib ; ln -sf libpolkit-agent-1.so.0.0.0 libpolkit-agent-1.so.0 )
( cd usr/lib ; rm -rf libpolkit-gobject-1.so )
( cd usr/lib ; ln -sf libpolkit-gobject-1.so.0.0.0 libpolkit-gobject-1.so )
( cd usr/lib ; rm -rf libpolkit-gobject-1.so.0 )
( cd usr/lib ; ln -sf libpolkit-gobject-1.so.0.0.0 libpolkit-gobject-1.so.0 )
